@@ -226,7 +226,7 @@ int main(int argc, char **argv)
 	{ // handle a user entry
 	    if ( !(name = get_name(&lstname, newname)) )
 	    {
-			name = (struct t_name*)list_add(&lstname, sizeof(struct t_name));
+			name = (struct t_name*)ll_list_add(&lstname, sizeof(struct t_name));
 			strcpy(name->name, newname);
 			name->secs = newsecs;
 			if ( havecosts )
@@ -248,7 +248,7 @@ int main(int argc, char **argv)
 	{ // handle a line/manually entry
 	    if ( !(name = get_name(&lstline, newname)) )
 	    {
-			name = (struct t_name*)list_add(&lstline, sizeof(struct t_name));
+			name = (struct t_name*)ll_list_add(&lstline, sizeof(struct t_name));
 			strcpy(name->name, newname);
 
 			name->secs = 0;
@@ -488,41 +488,40 @@ void dump()
 }
 
 float get_cost(struct tm start, struct tm stop) {
-    int iProcessedDays = 0, iTarif = -1, iCosts2 = -1;
+    int iTarif, iCosts2 = -1, n;
     float fCosts = 0;
     long int liStart, liStop, liDayStart, liDayStop, liStartAdd, liTmpStop;
 
-    liStart = mktime(&start);
-    liStop = mktime(&stop);
     liDayStart = start.tm_hour * 3600 + start.tm_min * 60 + start.tm_sec;
     liDayStop = stop.tm_hour * 3600 + stop.tm_min * 60 + stop.tm_sec;
+    n = (liDayStop - liDayStart) / 86400;
+    liStart = liDayStart;
+    liStop = liDayStop + (n + (liDayStop < liDayStart ? 1 : 0)) * 86400;
     while (liStart <= liStop)
+    {
+	liStartAdd = 86400 - liDayStart;
+	while(liDayStart < 86400 && (iTarif = get_tarif(liDayStart, days[start.tm_wday])) != -1)
 	{
-		iProcessedDays++;
-		liStartAdd = 86400 - liDayStart;
-		while ( (liDayStart < tarif[iTarif].end) || (liDayStart < 86400) )
-		{
-		    iTarif = get_tarif(liDayStart, days[start.tm_wday]);
-	    	if (iTarif > -1)
-			{
-                if (iCosts2 == -1) {
-			        iCosts2 = iTarif;
-                }
-				if ((liDayStop <= tarif[iTarif].end) && (liDayStop >= liDayStart))
-				{
-		    		liTmpStop = liDayStop;
-				}
-				else
-				{
-		    		liTmpStop = tarif[iTarif].end;
-				}
-//	        	fCosts += (liTmpStop - liDayStart) / tarif[iTarif].unit * tarif[iTarif].costs;
-		        fCosts += get_unit(liDayStart, liTmpStop, tarif[iTarif].unit) * tarif[iTarif].costs;
-				liDayStart = tarif[iTarif].end + 1;
-	    	}
-		}
-		liStart += liStartAdd;
-		liDayStart = 0;
+	    if (iCosts2 == -1)
+	    {
+		iCosts2 = iTarif;
+	    }
+	    if ((liDayStop <= tarif[iTarif].end) && (liDayStop >= liDayStart))
+	    {
+	    	liTmpStop = liDayStop;
+	    }
+	    else
+	    {
+	        liTmpStop = tarif[iTarif].end;
+	    }
+//          fCosts += (liTmpStop - liDayStart) / tarif[iTarif].unit * tarif[iTarif].costs;
+	    fCosts += get_unit(liDayStart, liTmpStop, tarif[iTarif].unit) * tarif[iTarif].costs;
+	    liDayStart = tarif[iTarif].end + 1;
+	    if(liTmpStop == liDayStop)
+		break;
+	}
+	liStart += liStartAdd;
+	liDayStart = 0;
     }
     if (iCosts2 != -1) {
         fCosts += tarif[iCosts2].costs2;
@@ -547,7 +546,7 @@ int get_tarif(long int time, char weekday[4]) {
     for (i = 0; i < 255 && i < tarifcount; i++) {
 	strcpy(tarifweekday, tarif[i].weekday);
 	if (strcmp(tarifweekday, weekday) == 0) {
-	    if ((time >= tarif[i].begin) && (time < tarif[i].end)) {
+	    if ((time >= tarif[i].begin) && (time <= tarif[i].end)) {
 		iTarifIndex = i;
 	    }
 	}
@@ -556,7 +555,7 @@ int get_tarif(long int time, char weekday[4]) {
         for (i = 0; i < 255 && i < tarifcount; i++) {
 	    strcpy(tarifweekday, tarif[i].weekday);
 	    if (strcmp(tarifweekday, "*") == 0) {
-	        if ((time >= tarif[i].begin) && (time < tarif[i].end)) {
+	        if ((time >= tarif[i].begin) && (time <= tarif[i].end)) {
 		    iTarifIndex = i;
 		}
 	    }
@@ -567,29 +566,29 @@ int get_tarif(long int time, char weekday[4]) {
 }
 
 char get_month_id(char month[4]) {
-    if (month == "Jan") return 0;
-    else if (month == "Feb") return 1;
-    else if (month == "Mar") return 2;
-    else if (month == "Apr") return 3;
-    else if (month == "May") return 4;
-    else if (month == "Jun") return 5;
-    else if (month == "Jul") return 6;
-    else if (month == "Aug") return 7;
-    else if (month == "Sep") return 8;
-    else if (month == "Oct") return 9;
-    else if (month == "Nov") return 10;
-    else if (month == "Dec") return 11;
+    if (!strcmp(month, "Jan")) return 0;
+    else if (!strcmp(month, "Feb")) return 1;
+    else if (!strcmp(month, "Mar")) return 2;
+    else if (!strcmp(month, "Apr")) return 3;
+    else if (!strcmp(month, "May")) return 4;
+    else if (!strcmp(month, "Jun")) return 5;
+    else if (!strcmp(month, "Jul")) return 6;
+    else if (!strcmp(month, "Aug")) return 7;
+    else if (!strcmp(month, "Sep")) return 8;
+    else if (!strcmp(month, "Oct")) return 9;
+    else if (!strcmp(month, "Nov")) return 10;
+    else if (!strcmp(month, "Dec")) return 11;
     return -1;
 }
 
 char get_day_id(char day[4]) {
-    if (day == "Sun") return 0;
-    else if (day == "Mon") return 1;
-    else if (day == "Tue") return 2;
-    else if (day == "Wed") return 3;
-    else if (day == "Thu") return 4;
-    else if (day == "Fri") return 5;
-    else if (day == "Sat") return 6;
+    if (!strcmp(day, "Sun")) return 0;
+    else if (!strcmp(day, "Mon")) return 1;
+    else if (!strcmp(day, "Tue")) return 2;
+    else if (!strcmp(day, "Wed")) return 3;
+    else if (!strcmp(day, "Thu")) return 4;
+    else if (!strcmp(day, "Fri")) return 5;
+    else if (!strcmp(day, "Sat")) return 6;
     return -1;
 }
 		
