@@ -390,7 +390,7 @@ int read_config(int argc, char **argv)
  config_set_conf_addrs();
  config_load_defaults();
  /* create & init default line, id 0 */
- curline = (struct line_t*)list_add(&lstlines, sizeof(struct line_t));
+ curline = (struct line_t*)ll_list_add(&lstlines, sizeof(struct line_t));
  if ( !curline )
  {
      fprintf(stderr, "Not enough memory to load configuration.\n");
@@ -425,7 +425,7 @@ int read_config(int argc, char **argv)
 	    case LCS_CONF_LINE:
 		// integrity of current line gets checked at the end.
 		// let's begin with the settings of a new line
-		curline = (struct line_t*)list_add(&lstlines, sizeof(struct line_t));
+		curline = (struct line_t*)ll_list_add(&lstlines, sizeof(struct line_t));
 		if ( !curline )
 		{
 		    fprintf(stderr, "Not enough memory to load configuration.\n");
@@ -599,7 +599,7 @@ int read_config(int argc, char **argv)
 	        // ok, got new filter entry
 	        if (server->ipl_type != IPL_INVALID)
 	        {
-		    iplentry = (struct ipl_item_t*)list_add(&ipl, sizeof(struct ipl_item_t));
+		    iplentry = (struct ipl_item_t*)ll_list_add(&ipl, sizeof(struct ipl_item_t));
 		    if ( !iplentry )
 		    {
 		        server->ipl_type = IPL_INVALID;
@@ -632,7 +632,7 @@ int read_config(int argc, char **argv)
 	        // ok, got new shutdown - filter entry
 	        if (server->shtdn_ipl_type != IPL_INVALID)
 	        {
-		    iplentry = (struct ipl_item_t*)list_add(&shtdn_ipl, sizeof(struct ipl_item_t));
+		    iplentry = (struct ipl_item_t*)ll_list_add(&shtdn_ipl, sizeof(struct ipl_item_t));
 		    if ( !iplentry )
 		    {
 		        server->shtdn_ipl_type = IPL_INVALID;
@@ -661,6 +661,7 @@ int read_config(int argc, char **argv)
 		}
 		break;
 	    default:
+	    	;
 	}
     }
  }
