@@ -55,7 +55,7 @@ int cmd_q(struct client_t *who, int cmd, char *msg, int msglen)
  struct ordq_item_t *item;
  int efflen = LC_MAX_MSG_LEN;
  if ( msglen < efflen ) efflen = msglen;
- if ( (item = (struct ordq_item_t*)list_add(&ordq, sizeof(struct ordq_item_t))) == NULL )
+ if ( (item = (struct ordq_item_t*)ll_list_add(&ordq, sizeof(struct ordq_item_t))) == NULL )
  {
   syslog(LOG_WARNING, "cmd_q(): malloc(%d) returned NULL", sizeof(struct ordq_item_t));
   return(-2);
@@ -286,7 +286,7 @@ int ack_q(struct ordq_item_t *which) // moves cmd from ordq to ackq
  struct ackq_item_t *item;
  if ( which->cmd >= CBR_INFO ) return(0); // we shouldn't get acks for cmds
                                           // >= CBR_INFO, so block here.
- if ( (item = (struct ackq_item_t*)list_add(&ackq, sizeof(struct ackq_item_t))) == NULL )
+ if ( (item = (struct ackq_item_t*)ll_list_add(&ackq, sizeof(struct ackq_item_t))) == NULL )
  {
   syslog(LOG_WARNING, "ack_q(): malloc(%d) returned NULL", sizeof(struct ackq_item_t));
   return(-2);
