@@ -11,7 +11,7 @@ int cmd_direct_tcp(int cmd, int sock, struct sockaddr_in *, char *, int);
 int cmd_broadcast(int cbr, char *msg, int mlen);
 int ack_remove(struct p_order_t *pack, struct sockaddr_in *from);
 int ack_send(struct sockaddr_in *trg, struct p_order_t *cmdpack);
-int ack_proc(int ip, short port); // handels a received ack:
+int ack_proc(int ip, short port); // handles a received ack:
  // remove ackq entry
  // look for commands to send
 int ackq_check(); // looks for timed out acks
