@@ -22,7 +22,7 @@ void *get_output_buffer(int cmd)
 int lcp3_cmd_queue(int cmd, struct client_t *who, void* info, int infosize)
 {
     struct t_lcp3_ordq_item* newcmd;
-    if ( !(newcmd = (struct t_lcp3_ordq_item*)list_add(&lcp3_ordq, sizeof(struct t_lcp3_ordq_item))) )
+    if ( !(newcmd = (struct t_lcp3_ordq_item*)ll_list_add(&lcp3_ordq, sizeof(struct t_lcp3_ordq_item))) )
     {
 		syslog(LOG_ERR, "Out of memory. Unable to queue command.");
 		return(-1);
