@@ -69,7 +69,7 @@ int call_con_up(struct client_t *who, struct line_t *line)
  else
  {
 	 segf_indicator = 3207;
-     (struct client_t*)line->con_action.who = who;
+     line->con_action.who = who;
      line->con_action.begin = time(NULL);
      server->fast_loop++;
      set_line_status(line, CST_DIALING);
@@ -181,7 +181,7 @@ int call_con_dn(struct client_t *who, struct line_t *line)
  else // parent
  { // should work... go on.
      line->con_action.doing = DOING_CLOSING;
-     (struct client_t*)line->con_action.who = who;
+     line->con_action.who = who;
      line->con_action.begin = time(NULL);
      server->fast_loop++;
      set_line_status(line, CST_CLOSING);
@@ -315,7 +315,13 @@ segf_indicator = 22;
 			 who->status = CLT_ONLINE;
 			 who->started = time(NULL);
 			 line->online++;
-			 syslog(LOG_INFO, "%s:%d online", inet_ntoa(iaddr), ntohs(((struct client_t*)line->con_action.who)->port));
+
+			 // FIXME: is the right ipaddr:port reported? Can con_action.who be NULL? sfuchs 20040613
+			 if ( line->con_action.who )
+				 syslog(LOG_INFO, "%s:%d online", inet_ntoa(iaddr), ntohs(((struct client_t*)line->con_action.who)->port));
+			 else
+				 syslog(LOG_INFO, "<unknown> online (if you see this, report it to linecontrol[at]srf.ch, looks like segf 22 is fixed!)");
+			 
 			 // will get clt status update with CBR3_LINESTAT
 		         iaddr.s_addr = who->ip;
 		         if ( line->client_online[0] )
