@@ -63,7 +63,7 @@ int iface_up_normal(int socket_fd, const char *ifname)
 int iface_up_isdn(const char *id, const char *isdninfofile, int channel)
 /* I've had a look at imon.c ... */
 {
-#define LC_ISDN_LINE_LEN	4096
+#define LC_ISDN_LINE_LEN	2048
     FILE *isdninfo;
     char *ii_idmap;
     char *idptr;
@@ -76,6 +76,7 @@ int iface_up_isdn(const char *id, const char *isdninfofile, int channel)
     char drvid[15];
     int usage, chan, flags;
     int len, nmbr;
+    static char  fbuf[LC_ISDN_LINE_LEN];
 
     /* maybe we have to malloc/fopen global vars. But then we have to lock */
     if ( !(isdninfo = fopen(isdninfofile, "r")) )
@@ -84,6 +85,10 @@ int iface_up_isdn(const char *id, const char *isdninfofile, int channel)
 				isdninfofile);
 		return(-2); // error!
 	}
+
+    setvbuf(isdninfo, fbuf, _IOFBF, sizeof(fbuf));
+
+    
     if ( !(ii_idmap = malloc(LC_ISDN_LINE_LEN)) )
 	{ fclose(isdninfo); return(-2); }
     if ( !(ii_chmap = malloc(LC_ISDN_LINE_LEN)) )
