@@ -10,7 +10,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <asm/io.h>
 #include "lists.h"
 #include "../common.h"
 #include "srv_def.h"
@@ -31,6 +30,7 @@
 // I wasn't able to find a .h for ioperm(...) and iopl(...)
 // but it linked well when declared as extern... ??
 #ifdef LPT_MONITOR
+	#include <asm/io.h>
 	extern int ioperm(unsigned  long  from,  unsigned  long num, int turn_on);
 	extern int iopl(int level);
 #endif
@@ -50,7 +50,7 @@ void cleanup(int sig)
  syslog(LOG_DEBUG, "cleanup(): cought signal %d", sig);
  if ( sig == SIGSEGV )
  {
-     syslog(LOG_ERR, "SEGFAULT, please report to linecontrol@gmx.ch");
+     syslog(LOG_ERR, "SEGFAULT, please report to linecontrol@srf.ch");
      syslog(LOG_INFO, "Version: %s; Value of segf_indicator: %d",
 	 		LCS_VERSION_STR, segf_indicator);
  }
