@@ -8,6 +8,9 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <syslog.h>
+#include <fcntl.h>
+#include <string.h>
+#include <errno.h>
 #include "init.h"
 #include "global_vars.h"
 #include "../common.h"
@@ -94,9 +97,66 @@ int time_failure()
     return(0);
 }
 
+/*
+ * detach and become daemon - patch by Jonathan Rogers <jonner@teegra.net>
+ * roe: merged second fork back in and added chdir("/"), but maybe we should
+ * just call daemon() where available... ./configure integration anyone? :)
+ * See "Advanced Programming in a UNIX Environment" by W. Richard Stevens
+ * fuchs: added daemon() call where possible
+ */
+void detach() {
+#if HAVE_DAEMON
+	if ( daemon(0, 0) )
+	{
+    	fprintf(stderr, "unable to become a daemon, terminating.\n");
+    	cleanup();
+	}
+#else
+  int fd, newfd;
+  pid_t pid;
+
+  /* fork to guarantee that we're not session leader */
+  if ((pid = fork()) < 0)
+    {
+      fprintf(stderr, "unable to fork, terminating.\n");
+      cleanup();
+    }
+  else { if (pid > 0) exit(0); }
+
+  /* become session leader */
+  setsid();
+
+  /* fork again, to make sure we detach from TTY on *all* systems */
+  if ((pid = fork()) < 0)
+    {
+      fprintf(stderr, "unable to fork, terminating.\n");
+      cleanup();
+    }
+  else { if (pid > 0) exit(0); }
+
+  /* attach std{in,out,err} to /dev/null */
+  if ((newfd=open("/dev/null",O_RDWR)) < 0) {
+    syslog(LOG_ERR, "open(/dev/null) failed: %s", strerror(errno));
+    exit(-1);
+  }
+  for (fd=0; fd<3; fd++) {
+    if (dup2(newfd,fd) < 0) {
+      syslog(LOG_ERR, "dup2() failed: %s", strerror(errno));
+      exit(-1);
+    }
+  }
+  if (close(newfd) < 0) {
+    syslog(LOG_ERR, "close() failed: %s", strerror(errno));
+    exit(-1);
+  }
+
+  /* change to / to prevent locking the old working directory */
+  chdir("/");
+#endif
+}
+
 int main(int argc, char *argv[])
 {
- pid_t pid;
  struct sockaddr_in from;
  struct p_order_t pack;
  int rlen, len;
@@ -117,20 +177,9 @@ int main(int argc, char *argv[])
      // quite everything has to get cleaned up by the operatingsystem!
      exit(-1);
  }
- fprintf(stdout, "%s %s leaving the console...\n", LCS_NAME, LCS_VERSION_STR);
 #ifndef STAY_TTY
- if ((pid = fork()) < 0)
- {
-    fprintf(stderr, "unable to fork, terminating.\n");
-    cleanup();
- }
- else { if (pid > 0) return(0); }
- setsid();
- if ((pid = fork()) < 0) {
-     fprintf(stderr, "unable to fork, terminating.\n");
-     cleanup();
- }
- else { if (pid > 0) return(0); }
+ fprintf(stdout, "%s %s leaving the console...\n", LCS_NAME, LCS_VERSION_STR);
+ detach();
 #endif /* STAY_TTY */
  syslog(LOG_INFO, "%s %s started.", LCS_NAME, LCS_VERSION_STR);
  // dump our pid to a file...
