@@ -14,7 +14,7 @@ struct list_anchor_t {
 };
 
 void list_init(struct list_anchor_t *list);
-struct list_hdr_t *list_add(struct list_anchor_t *list, int size);
+struct list_hdr_t *ll_list_add(struct list_anchor_t *list, int size);
 void  list_del(struct list_anchor_t *list, struct list_hdr_t *item);
 void  list_flush(struct list_anchor_t *list);
 int   list_count(struct list_anchor_t *list);
