@@ -159,7 +159,7 @@ int process_lcp3_order(struct t_lcp3_cmd *pack, struct sockaddr_in *from, int so
 			    who->status = CLT_OFFLINE;
 			    break;
 			default:
-			    // uh... don't dial -> status would be incorrect
+			    ; // uh... don't dial -> status would be incorrect
 	    }
 	    lcp3_cmd_queue(CMD3_CLIENTSTAT, who, NULL, 0);
 	    break; // CMD3_ONLINE
